<?php
session_start();
header('Content-Type: application/json');

// Conexión a la base de datos
require_once 'config.php';

// Verificar si se recibieron los datos necesarios
if (!isset($_POST['phone']) || !isset($_POST['firebase_uid'])) {
    echo json_encode(['error' => 'Faltan datos requeridos']);
    exit();
}

$phone = $conn->real_escape_string($_POST['phone']);
$firebase_uid = $conn->real_escape_string($_POST['firebase_uid']);

// Verificar si el usuario existe
$query = "SELECT id, name FROM users WHERE phone = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param("s", $phone);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    // Usuario existente
    $user = $result->fetch_assoc();
    
    // Actualizar última sesión
    $update_query = "UPDATE users SET last_login = NOW() WHERE id = ?";
    $update_stmt = $conn->prepare($update_query);
    $update_stmt->bind_param("i", $user['id']);
    $update_stmt->execute();
    
    // Crear sesión
    $_SESSION['user_id'] = $user['id'];
    $_SESSION['name'] = $user['name'];
    $_SESSION['phone'] = $phone;
    $_SESSION['firebase_uid'] = $firebase_uid;
    
    echo json_encode(['exists' => true, 'name' => $user['name']]);
} else {
    // Nuevo usuario
    echo json_encode(['exists' => false]);
}

$stmt->close();
$conn->close();
?>