<?php
session_start();

// Verificar si el usuario está autenticado
if (!isset($_SESSION['user_id'])) {
    header('Location: login.php');
    exit();
}

// Datos del usuario
$user_id = $_SESSION['user_id'];
$name = $_SESSION['name'];
$phone = $_SESSION['phone'];

// Conexión a la base de datos
require_once 'config.php';

// --- SOLO OBTENER CONVERSACIONES EXISTENTES ---
$chats_query = "
    SELECT
        u.id, u.name, u.phone,
        (SELECT message FROM messages
         WHERE (sender_id = ? AND receiver_id = u.id) OR (sender_id = u.id AND receiver_id = ?)
         ORDER BY timestamp DESC LIMIT 1) as last_message,
        (SELECT timestamp FROM messages
         WHERE (sender_id = ? AND receiver_id = u.id) OR (sender_id = u.id AND receiver_id = ?)
         ORDER BY timestamp DESC LIMIT 1) as last_timestamp,
        (SELECT COUNT(*) FROM messages
         WHERE sender_id = u.id AND receiver_id = ? AND `read` = 0) as unread_count
    FROM
        users u
    WHERE
        u.id != ? AND
        EXISTS (
            SELECT 1 FROM messages
            WHERE (sender_id = ? AND receiver_id = u.id) OR (sender_id = u.id AND receiver_id = ?)
        )
    ORDER BY
        COALESCE(last_timestamp, '1970-01-01') DESC /* Ordenar por fecha, poniendo los nulos al final */
";
$chats_stmt = $conn->prepare($chats_query);
// Asegúrate de que el número y tipo de 'i' coincidan exactamente con los '?' en la consulta (8 'i')
$chats_stmt->bind_param("iiiiiiii", $user_id, $user_id, $user_id, $user_id, $user_id, $user_id, $user_id, $user_id);
$chats_stmt->execute();
$chats_result = $chats_stmt->get_result();
$initial_chats = [];
while ($row = $chats_result->fetch_assoc()) {
    $initial_chats[] = $row;
}
$chats_stmt->close();

// --- YA NO SE CARGAN TODOS LOS USUARIOS AQUÍ ---

$conn->close(); // Cerrar conexión después de usarla
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>FlyChat - Dashboard</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <style>
        .blue-gradient {
            background: linear-gradient(135deg, #0088cc 0%, #0055a5 100%);
        }
        .chat-item:hover {
            background-color: rgba(59, 130, 246, 0.05);
        }
        /* Añadido para el spinner */
        .loader {
            border: 4px solid #f3f3f3; /* Light grey */
            border-top: 4px solid #3498db; /* Blue */
            border-radius: 50%;
            width: 20px;
            height: 20px;
            animation: spin 1s linear infinite;
            margin: 5px auto; /* Para centrarlo si está solo */
            display: inline-block; /* Para que esté al lado del texto si es necesario */
        }

        @keyframes spin {
            0% { transform: rotate(0deg); }
            100% { transform: rotate(360deg); }
        }
        /* Asegurar que los contenedores de resultados y chats no se solapen */
        #chats-container, #search-results, #no-results {
           min-height: 100px; /* Evita colapso al ocultar/mostrar */
        }
    </style>
</head>
<body class="bg-gray-100 h-screen flex flex-col">
    <header class="blue-gradient text-white p-4 flex justify-between items-center">
        <h1 class="text-xl font-bold">FlyChat</h1>
        <div class="flex items-center">
            <span id="loading-indicator" class="hidden mr-2"><div class="loader"></div></span> <!-- Indicador de carga -->
            <button id="menu-btn" class="p-2 text-xl">
                <i class="fas fa-bars"></i>
            </button>
        </div>
    </header>

    <!-- Menú lateral (oculto por defecto en móvil) -->
    <div id="side-menu" class="fixed inset-0 bg-black bg-opacity-50 z-50 hidden flex">
        <div class="w-64 h-full bg-white flex flex-col shadow-lg">
            <div class="blue-gradient p-4 text-white flex items-center justify-between">
                 <div class="flex items-center">
                    <div class="w-12 h-12 rounded-full bg-blue-300 flex items-center justify-center text-blue-800 font-bold mr-3 flex-shrink-0">
                        <span id="user-initials"><?php echo strtoupper(substr($name, 0, 1)); ?></span>
                    </div>
                    <div class="overflow-hidden">
                        <h2 id="user-name" class="font-bold truncate"><?php echo htmlspecialchars($name); ?></h2>
                        <p id="user-phone" class="text-sm text-blue-100 truncate"><?php echo htmlspecialchars($phone); ?></p>
                    </div>
                </div>
            </div>
            <div class="flex-1 p-2 overflow-y-auto">
                <a href="#" class="block p-3 rounded hover:bg-gray-100">
                    <i class="fas fa-user-friends fa-fw mr-2"></i> Contactos
                </a>
                <a href="#" class="block p-3 rounded hover:bg-gray-100">
                    <i class="fas fa-cog fa-fw mr-2"></i> Configuración
                </a>
                <a href="#" class="block p-3 rounded hover:bg-gray-100">
                    <i class="fas fa-question-circle fa-fw mr-2"></i> Ayuda
                </a>
            </div>
            <div class="p-3 border-t">
                <a href="logout.php" class="block w-full py-2 px-4 text-red-500 rounded hover:bg-red-50 text-left">
                    <i class="fas fa-sign-out-alt fa-fw mr-2"></i> Cerrar sesión
                </a>
            </div>
        </div>
        <div class="flex-1" onclick="closeSideMenu()"></div> <!-- Overlay para cerrar -->
    </div>

    <!-- Buscador -->
    <div class="p-3 bg-white border-b">
        <div class="relative">
            <input type="search" id="search-input"
                   placeholder="Buscar por nombre o número exacto..."
                   class="w-full pl-10 pr-4 py-2 rounded-full border focus:outline-none focus:ring-2 focus:ring-blue-500">
            <div class="absolute left-3 top-1/2 transform -translate-y-1/2 text-gray-400">
                <i class="fas fa-search"></i>
            </div>
             <span id="search-loading-indicator" class="absolute right-3 top-1/2 transform -translate-y-1/2 hidden"><div class="loader !w-5 !h-5"></div></span> <!-- Spinner para búsqueda -->
        </div>
    </div>

    <!-- Contenedor principal para listas -->
    <div class="flex-1 overflow-y-auto bg-white">
        <!-- Contenedor de chats existentes (se muestra por defecto) -->
        <div id="chats-container">
             <div class="px-4 py-2 text-sm font-semibold text-gray-500 uppercase sticky top-0 bg-white z-10">Conversaciones recientes</div>
             <div id="chats-list">
                <?php if (empty($initial_chats)): ?>
                    <div class="p-4 text-center text-gray-500" id="no-chats-message">
                        No tienes conversaciones recientes. <br> Usa la barra de búsqueda para encontrar usuarios e iniciar un chat.
                    </div>
                <?php else: ?>
                    <?php foreach ($initial_chats as $chat): ?>
                        <?php
                        $initials = strtoupper(substr($chat['name'], 0, 1));
                        $timestamp = '';
                        if ($chat['last_timestamp']) {
                           $ts = strtotime($chat['last_timestamp']);
                           if (date('Y-m-d', $ts) == date('Y-m-d')) {
                               $timestamp = date('H:i', $ts);
                           } else {
                               $timestamp = date('d/m', $ts);
                           }
                        }
                        ?>
                        <div class="chat-item flex p-3 border-b cursor-pointer" data-user-id="<?php echo $chat['id']; ?>" onclick="openChat(<?php echo $chat['id']; ?>)">
                            <div class="w-12 h-12 rounded-full bg-blue-100 flex items-center justify-center text-blue-800 font-bold mr-3 flex-shrink-0">
                                <span><?php echo htmlspecialchars($initials); ?></span>
                            </div>
                            <div class="flex-1 overflow-hidden">
                                <div class="flex justify-between items-start">
                                    <h3 class="font-semibold truncate mr-2"><?php echo htmlspecialchars($chat['name']); ?></h3>
                                    <span class="text-xs text-gray-500 flex-shrink-0 ml-2"><?php echo $timestamp; ?></span>
                                </div>
                                <div class="flex justify-between items-center mt-1">
                                    <p class="text-sm text-gray-600 truncate flex-1 mr-2"><?php echo $chat['last_message'] ? htmlspecialchars($chat['last_message']) : 'Inicia la conversación'; ?></p>
                                    <?php if ($chat['unread_count'] > 0): ?>
                                    <div class="flex-shrink-0 self-center">
                                        <span class="bg-blue-500 text-white text-xs font-medium px-2 py-1 rounded-full"><?php echo $chat['unread_count']; ?></span>
                                    </div>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                <?php endif; ?>
            </div> <!-- Fin de #chats-list -->
        </div> <!-- Fin de #chats-container -->

        <!-- Contenedor para resultados de búsqueda (oculto por defecto) -->
        <div id="search-results" class="hidden">
             <div class="px-4 py-2 text-sm font-semibold text-gray-500 uppercase sticky top-0 bg-white z-10">Resultados de búsqueda</div>
            <div id="search-results-container">
                <!-- Los resultados de la búsqueda se insertarán aquí -->
            </div>
        </div>

        <!-- Mensaje cuando no hay resultados de búsqueda (oculto por defecto) -->
        <div id="no-results" class="hidden p-8 text-center">
            <div class="text-gray-400 mb-3">
                <i class="fas fa-user-slash text-4xl"></i>
            </div>
            <p class="text-gray-500">No se encontró ningún usuario con ese nombre o número.</p>
        </div>
    </div>

    <!-- Botón flotante ELIMINADO -->

    <script>
        // --- Elementos del DOM ---
        const menuBtn = document.getElementById('menu-btn');
        const sideMenu = document.getElementById('side-menu');
        const chatsContainer = document.getElementById('chats-container'); // Contenedor general de chats
        const chatsListContainer = document.getElementById('chats-list'); // Lista específica de chats
        const noChatsMessage = document.getElementById('no-chats-message'); // Mensaje si no hay chats
        const searchInput = document.getElementById('search-input');
        const searchResults = document.getElementById('search-results'); // Contenedor general de resultados
        const searchResultsContainer = document.getElementById('search-results-container'); // Lista específica de resultados
        const noResults = document.getElementById('no-results'); // Mensaje si no hay resultados
        const loadingIndicator = document.getElementById('loading-indicator'); // Spinner general (header)
        const searchLoadingIndicator = document.getElementById('search-loading-indicator'); // Spinner en barra de búsqueda

        // --- Variables Globales ---
        const currentUser = {
            id: <?php echo $user_id; ?>,
            name: "<?php echo addslashes(htmlspecialchars($name)); ?>",
            phone: "<?php echo addslashes(htmlspecialchars($phone)); ?>",
            initials: "<?php echo strtoupper(substr($name, 0, 1)); ?>"
        };
        let pollingIntervalId = null;
        const POLLING_INTERVAL = 5000; // 5 segundos
        let searchTimeoutId = null; // Para debounce de la búsqueda
        const SEARCH_DEBOUNCE_DELAY = 300; // ms

        // --- Funciones de Utilidad ---
        function escapeHTML(str) {
            if (typeof str !== 'string') return '';
            const div = document.createElement('div');
            div.appendChild(document.createTextNode(str));
            return div.innerHTML;
        }

        // --- Funciones del Menú y UI ---
        function openSideMenu() {
            sideMenu.classList.remove('hidden');
            menuBtn.innerHTML = '<i class="fas fa-times"></i>';
        }

        function closeSideMenu() {
            sideMenu.classList.add('hidden');
            menuBtn.innerHTML = '<i class="fas fa-bars"></i>';
        }

        function toggleSideMenu() {
            sideMenu.classList.toggle('hidden');
            menuBtn.innerHTML = sideMenu.classList.contains('hidden') ? '<i class="fas fa-bars"></i>' : '<i class="fas fa-times"></i>';
        }

        // --- Funcionalidad de Búsqueda (AJAX) ---
        async function performSearch() {
            const query = searchInput.value.trim();
            searchResultsContainer.innerHTML = ''; // Limpiar resultados anteriores
            searchResults.classList.add('hidden');
            noResults.classList.add('hidden');

            // Si la búsqueda está vacía, restaurar vista de chats
            if (query === '') {
                chatsContainer.classList.remove('hidden');
                searchLoadingIndicator.classList.add('hidden'); // Ocultar spinner de búsqueda
                startChatPolling(); // Reanudar polling
                return; // Salir de la función
            }

            // Si hay búsqueda, ocultar chats y detener polling
            stopChatPolling();
            chatsContainer.classList.add('hidden');
            searchLoadingIndicator.classList.remove('hidden'); // Mostrar spinner de búsqueda

            try {
                const response = await fetch(`search_users.php?query=${encodeURIComponent(query)}`);
                if (!response.ok) {
                    throw new Error(`HTTP error! status: ${response.status}`);
                }
                const users = await response.json();

                if (users.length > 0) {
                    displaySearchResults(users);
                    searchResults.classList.remove('hidden');
                } else {
                    noResults.classList.remove('hidden');
                }

            } catch (error) {
                console.error('Error during search:', error);
                searchResultsContainer.innerHTML = '<p class="p-4 text-red-500">Error al realizar la búsqueda.</p>';
                searchResults.classList.remove('hidden'); // Mostrar el contenedor para ver el error
                noResults.classList.add('hidden');
            } finally {
                 searchLoadingIndicator.classList.add('hidden'); // Ocultar spinner de búsqueda
            }
        }

        function displaySearchResults(users) {
             searchResultsContainer.innerHTML = ''; // Limpiar por si acaso
             users.forEach(user => {
                const initials = escapeHTML(user.name ? user.name.substring(0, 1).toUpperCase() : '?');
                const name = escapeHTML(user.name || 'Usuario desconocido');
                const phone = escapeHTML(user.phone || 'Sin número');

                const userElementHTML = `
                    <div class="chat-item flex p-3 border-b cursor-pointer" data-user-id="${user.id}" onclick="openChat(${user.id})">
                        <div class="w-12 h-12 rounded-full bg-blue-100 flex items-center justify-center text-blue-800 font-bold mr-3 flex-shrink-0">
                            <span>${initials}</span>
                        </div>
                        <div class="flex-1 overflow-hidden">
                            <div class="flex justify-between">
                                <h3 class="font-semibold truncate">${name}</h3>
                            </div>
                            <p class="text-sm text-gray-600 truncate">${phone}</p>
                        </div>
                    </div>
                `;
                searchResultsContainer.insertAdjacentHTML('beforeend', userElementHTML);
             });
        }


        // --- Funcionalidad de Chat ---
        function openChat(userId) {
            stopChatPolling(); // Detener polling antes de navegar
            window.location.href = 'chat.php?id=' + userId;
        }

        // --- Carga en Tiempo Real (Polling) ---
        function updateChatListUI(chats) {
            // Guardar scroll position si es necesario antes de limpiar
            // const scrollPosition = chatsListContainer.scrollTop;

            chatsListContainer.innerHTML = ''; // Limpiar la lista actual

            if (!chats || chats.length === 0) {
                 // Mostrar mensaje solo si no hay uno ya y el contenedor está vacío
                 if (!document.getElementById('no-chats-message')) {
                      chatsListContainer.innerHTML = `
                        <div class="p-4 text-center text-gray-500" id="no-chats-message">
                            No tienes conversaciones recientes. <br> Usa la barra de búsqueda para encontrar usuarios e iniciar un chat.
                        </div>`;
                 }
            } else {
                // Ocultar mensaje si existe y vamos a añadir chats
                const existingNoChatsMsg = document.getElementById('no-chats-message');
                if (existingNoChatsMsg) existingNoChatsMsg.remove();

                chats.forEach(chat => {
                    const initials = escapeHTML(chat.name ? chat.name.substring(0, 1).toUpperCase() : '?');
                    const name = escapeHTML(chat.name || 'Usuario desconocido');
                    const lastMessage = escapeHTML(chat.last_message || 'Inicia la conversación');
                    const timestamp = chat.formatted_timestamp || ''; // Ya viene formateado
                    const unreadCount = chat.unread_count || 0;

                    const chatElementHTML = `
                        <div class="chat-item flex p-3 border-b cursor-pointer" data-user-id="${chat.id}" onclick="openChat(${chat.id})">
                            <div class="w-12 h-12 rounded-full bg-blue-100 flex items-center justify-center text-blue-800 font-bold mr-3 flex-shrink-0">
                                <span>${initials}</span>
                            </div>
                            <div class="flex-1 overflow-hidden">
                                <div class="flex justify-between items-start">
                                    <h3 class="font-semibold truncate mr-2">${name}</h3>
                                    <span class="text-xs text-gray-500 flex-shrink-0">${timestamp}</span>
                                </div>
                                <div class="flex justify-between items-center mt-1">
                                    <p class="text-sm text-gray-600 truncate flex-1 mr-2">${lastMessage}</p>
                                    ${unreadCount > 0 ? `
                                    <div class="flex-shrink-0 self-center">
                                        <span class="bg-blue-500 text-white text-xs font-medium px-2 py-1 rounded-full">${unreadCount}</span>
                                    </div>
                                    ` : ''}
                                </div>
                            </div>
                        </div>
                    `;
                    chatsListContainer.insertAdjacentHTML('beforeend', chatElementHTML);
                });
            }
             // Restaurar scroll position si se guardó
             // chatsListContainer.scrollTop = scrollPosition;
        }

        async function fetchAndUpdateChats() {
            // Solo actualizar si la vista de chats está activa Y no hay búsqueda activa
            if (!chatsContainer.classList.contains('hidden') && searchInput.value.trim() === '') {
                loadingIndicator.classList.remove('hidden'); // Usar el spinner del header para polling
                try {
                    const response = await fetch('get_updated_chats.php'); // Asumiendo que tienes este endpoint
                    if (!response.ok) {
                        if (response.status === 401) {
                            console.error('Error de autenticación. Deteniendo actualizaciones.');
                            stopChatPolling();
                            // Considera redirigir a login
                            // window.location.href = 'login.php';
                        } else {
                            throw new Error(`HTTP error! status: ${response.status}`);
                        }
                        return;
                    }
                    const chats = await response.json();
                    updateChatListUI(chats);
                } catch (error) {
                    console.error('Error fetching or updating chats:', error);
                    // Quizás detener polling si hay errores repetidos
                } finally {
                     loadingIndicator.classList.add('hidden');
                }
            } else {
                 // Si no estamos en la vista de chats o hay una búsqueda activa, asegurarse que el polling esté detenido.
                 stopChatPolling();
            }
        }

        function startChatPolling() {
            // Iniciar solo si no está ya corriendo, la vista de chats está visible Y el input de búsqueda está vacío
            if (pollingIntervalId === null && !chatsContainer.classList.contains('hidden') && searchInput.value.trim() === '') {
                 console.log('Attempting to start chat polling...');
                 fetchAndUpdateChats(); // Ejecutar inmediatamente al iniciar/reanudar
                 pollingIntervalId = setInterval(fetchAndUpdateChats, POLLING_INTERVAL);
                 console.log('Chat polling started.');
            } else {
                 console.log('Chat polling conditions not met, not starting.');
            }
        }

        function stopChatPolling() {
            if (pollingIntervalId !== null) {
                clearInterval(pollingIntervalId);
                pollingIntervalId = null;
                loadingIndicator.classList.add('hidden'); // Asegurarse que el spinner general se oculte
                console.log('Chat polling stopped.');
            }
        }

        // --- Inicialización ---
        document.addEventListener('DOMContentLoaded', function() {
            // Configurar eventos
            menuBtn.addEventListener('click', toggleSideMenu);

            // Evento de búsqueda con debounce
            searchInput.addEventListener('input', () => {
                clearTimeout(searchTimeoutId); // Cancelar timeout anterior
                // Ocultar resultados inmediatamente mientras se escribe
                searchResults.classList.add('hidden');
                noResults.classList.add('hidden');
                searchLoadingIndicator.classList.add('hidden'); // Ocultar spinner hasta que empiece la búsqueda real

                const query = searchInput.value.trim();
                if (query === '') {
                     // Si se borra el input, mostrar chats y reanudar polling inmediatamente
                     chatsContainer.classList.remove('hidden');
                     startChatPolling();
                } else {
                     // Si hay texto, esperar antes de buscar
                     stopChatPolling(); // Detener polling mientras se escribe/espera
                     searchTimeoutId = setTimeout(performSearch, SEARCH_DEBOUNCE_DELAY);
                }
            });

             // Cerrar menú si se hace clic fuera (en el overlay)
             sideMenu.querySelector('.flex-1').addEventListener('click', closeSideMenu);

             // Iniciar polling solo si la vista inicial es la de chats (por defecto lo es)
             startChatPolling();

            // Pausar/Reanudar polling con visibilidad de la pestaña/ventana
             document.addEventListener('visibilitychange', () => {
                if (document.hidden) {
                    stopChatPolling();
                } else {
                    // Reanudar solo si la vista de chats está activa y no hay búsqueda
                    if (!chatsContainer.classList.contains('hidden') && searchInput.value.trim() === '') {
                         startChatPolling();
                    }
                }
             });

             // Detener polling al cerrar la página/navegar fuera
             window.addEventListener('beforeunload', stopChatPolling);
        });

    </script>
</body>
</html>