<?php
session_start();
require_once 'config.php';

// Verificar autenticación
if (!isset($_SESSION['user_id'])) {
    header('Content-Type: application/json');
    echo json_encode(['status' => 'error', 'message' => 'No autenticado']);
    exit();
}

// Verificar método y datos
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    header('Content-Type: application/json');
    echo json_encode(['status' => 'error', 'message' => 'Método no permitido']);
    exit();
}

// Obtener datos JSON
$data = json_decode(file_get_contents('php://input'), true);
if (!$data) {
    header('Content-Type: application/json');
    echo json_encode(['status' => 'error', 'message' => 'Datos inválidos']);
    exit();
}

$user_id = $_SESSION['user_id'];
$other_user_id = isset($data['other_user_id']) ? intval($data['other_user_id']) : 0;
$status = isset($data['status']) ? $data['status'] : '';
$start_time = isset($data['start_time']) ? $data['start_time'] : null;
$end_time = isset($data['end_time']) ? $data['end_time'] : null;
$duration = isset($data['duration']) ? intval($data['duration']) : null;
$is_caller = isset($data['is_caller']) ? (bool)$data['is_caller'] : true;

// Validar datos
if (!$other_user_id || !in_array($status, ['initiated', 'answered', 'missed', 'rejected', 'ended'])) {
    header('Content-Type: application/json');
    echo json_encode(['status' => 'error', 'message' => 'Datos inválidos o incompletos']);
    exit();
}

// Determinar caller_id y receiver_id basado en is_caller
$caller_id = $is_caller ? $user_id : $other_user_id;
$receiver_id = $is_caller ? $other_user_id : $user_id;

// Preparar la consulta SQL basada en el estado
if ($status === 'initiated') {
    // Nueva llamada iniciada
    $query = "INSERT INTO call_logs (caller_id, receiver_id, status, start_time) VALUES (?, ?, ?, NOW())";
    $stmt = $conn->prepare($query);
    $stmt->bind_param("iis", $caller_id, $receiver_id, $status);
} 
else if ($status === 'ended' && $start_time) {
    // Actualizar una llamada existente con tiempo de finalización y duración
    $query = "UPDATE call_logs SET status = ?, end_time = NOW(), duration = ? 
              WHERE caller_id = ? AND receiver_id = ? AND DATE(start_time) = DATE(?) 
              ORDER BY id DESC LIMIT 1";
    $stmt = $conn->prepare($query);
    $stmt->bind_param("siiss", $status, $duration, $caller_id, $receiver_id, $start_time);
} 
else {
    // Actualizar estado de una llamada existente (missed, rejected, answered)
    $query = "UPDATE call_logs SET status = ? 
              WHERE caller_id = ? AND receiver_id = ? 
              ORDER BY id DESC LIMIT 1";
    $stmt = $conn->prepare($query);
    $stmt->bind_param("sii", $status, $caller_id, $receiver_id);
}

if ($stmt->execute()) {
    // Si fue una inserción, obtener el ID
    $call_id = ($status === 'initiated') ? $conn->insert_id : 0;
    
    header('Content-Type: application/json');
    echo json_encode([
        'status' => 'success', 
        'message' => 'Registro actualizado', 
        'call_id' => $call_id
    ]);
} else {
    header('Content-Type: application/json');
    echo json_encode([
        'status' => 'error', 
        'message' => 'Error al actualizar: ' . $stmt->error
    ]);
}

$stmt->close();
$conn->close();
?>