<?php
session_start();
header('Content-Type: application/json'); // Siempre devolver JSON

// Verificar autenticación
if (!isset($_SESSION['user_id'])) {
    http_response_code(401); // Unauthorized
    echo json_encode(['error' => 'Usuario no autenticado.']);
    exit();
}

// Validar que se recibió el parámetro 'query'
if (!isset($_GET['query']) || empty(trim($_GET['query']))) {
    echo json_encode([]); // Devolver array vacío si no hay query
    exit();
}

require_once 'config.php'; // Conexión a la base de datos

$current_user_id = $_SESSION['user_id'];
$search_query = trim($_GET['query']);

// --- Lógica para normalizar el teléfono ---
// Eliminar '+57' y espacios del término de búsqueda si parece un número
$normalized_phone_query = preg_replace('/[^0-9]/', '', $search_query); // Quitar todo excepto números
// Si el original empezaba con +57, quitamos 57 del inicio del normalizado para buscar sin prefijo tambien
if (strpos($search_query, '+57') === 0) {
    $normalized_phone_query_without_prefix = preg_replace('/^57/', '', $normalized_phone_query, 1);
} else {
    $normalized_phone_query_without_prefix = $normalized_phone_query; // Ya no tenía prefijo
}
// Ahora $normalized_phone_query_without_prefix contiene solo dígitos, sin el 57 si venía al inicio.


// --- Consulta SQL Preparada ---
// Buscamos coincidencia exacta de nombre O coincidencia del número normalizado
// Normalizamos el campo `phone` en la consulta para comparar
$sql = "SELECT id, name, phone
        FROM users
        WHERE id != ? AND (
            name = ?
            OR REPLACE(REPLACE(REPLACE(phone, '+57', ''), ' ', ''), '-', '') = ?
        )";

$stmt = $conn->prepare($sql);

if (!$stmt) {
    http_response_code(500); // Internal Server Error
    // En producción, loguear el error: error_log("Prepare failed: (" . $conn->errno . ") " . $conn->error);
    echo json_encode(['error' => 'Error preparando la consulta.']);
    exit();
}

// Bind parameters: User ID, Nombre exacto, Número normalizado sin prefijo
$stmt->bind_param("iss", $current_user_id, $search_query, $normalized_phone_query_without_prefix);

$results = [];
if ($stmt->execute()) {
    $result_set = $stmt->get_result();
    while ($row = $result_set->fetch_assoc()) {
        $results[] = $row;
    }
} else {
    http_response_code(500); // Internal Server Error
    // En producción, loguear el error: error_log("Execute failed: (" . $stmt->errno . ") " . $stmt->error);
    echo json_encode(['error' => 'Error ejecutando la búsqueda.']);
    $stmt->close();
    $conn->close();
    exit();
}

$stmt->close();
$conn->close();

echo json_encode($results); // Devolver resultados como JSON
?>