<?php
session_start();
require_once 'config.php';

$error = '';
$phone_to_verify = $_GET['phone'] ?? $_SESSION['phone_to_verify'] ?? ''; // Obtener teléfono de GET o sesión

// Redirigir si no hay teléfono para verificar o si ya está logueado
if (empty($phone_to_verify) || isset($_SESSION['user_id'])) {
    header('Location: index.php');
    exit();
}

// Mostrar el OTP simulado si está en sesión (SOLO PARA PRUEBAS)
$simulated_otp = $_SESSION['otp_for_testing'] ?? null;
unset($_SESSION['otp_for_testing']); // Limpiar después de mostrarlo

// Procesar envío de OTP
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $otp_entered = isset($_POST['otp']) ? trim($_POST['otp']) : '';

    if (empty($otp_entered)) {
        $error = "Por favor, ingresa el código OTP.";
    } else {
        // Buscar usuario y OTP en la base de datos
        $query = "SELECT id, name, otp_code, otp_expires_at FROM users WHERE phone = ? AND is_verified = 0";
        $stmt = $conn->prepare($query);
        if(!$stmt){
             error_log("Error preparando consulta de verificación OTP: " . $conn->error);
             $error = "Error del servidor. Inténtalo más tarde.";
        } else {
            $stmt->bind_param("s", $phone_to_verify);
            $stmt->execute();
            $result = $stmt->get_result();

            if ($result->num_rows > 0) {
                $user = $result->fetch_assoc();
                $now = date('Y-m-d H:i:s');

                // Verificar si el OTP coincide y no ha expirado
                if ($user['otp_code'] === $otp_entered && $user['otp_expires_at'] >= $now) {
                    // OTP correcto y válido
                    // Marcar usuario como verificado y limpiar OTP
                    $update_query = "UPDATE users SET is_verified = 1, otp_code = NULL, otp_expires_at = NULL, last_login = NOW() WHERE id = ?";
                    $update_stmt = $conn->prepare($update_query);
                    $update_stmt->bind_param("i", $user['id']);

                    if ($update_stmt->execute()) {
                        // Iniciar sesión
                        $_SESSION['user_id'] = $user['id'];
                        $_SESSION['name'] = $user['name'];
                        $_SESSION['phone'] = $phone_to_verify; // Guardar el teléfono verificado
                        unset($_SESSION['phone_to_verify']); // Limpiar de la sesión

                        // Actualizar estado a online
                        $update_status_query = "INSERT INTO user_status (user_id, status, last_activity) VALUES (?, 'online', NOW()) ON DUPLICATE KEY UPDATE status = 'online', last_activity = NOW()";
                        $status_stmt = $conn->prepare($update_status_query);
                         if($status_stmt){
                              $status_stmt->bind_param("i", $user['id']);
                              $status_stmt->execute();
                              $status_stmt->close();
                         } else {
                              error_log("Error preparando consulta de estado post-verificación: " . $conn->error);
                         }


                        $update_stmt->close();
                        $conn->close();
                        header('Location: dashboard.php');
                        exit();
                    } else {
                        $error = "Error al verificar la cuenta. Inténtalo de nuevo.";
                        error_log("Error actualizando estado verificado: " . $conn->error);
                    }
                     if(isset($update_stmt)) $update_stmt->close();

                } elseif ($user['otp_expires_at'] < $now) {
                    $error = "El código OTP ha expirado. Por favor, solicita uno nuevo registrándote de nuevo.";
                     // Opcional: Podrías añadir un botón "Reenviar OTP" que llame a una lógica similar a la de registro
                } else {
                    $error = "El código OTP ingresado es incorrecto.";
                }
            } else {
                $error = "No se encontró una solicitud de verificación pendiente para este número o ya está verificado.";
            }
            $stmt->close();
        }
    }
}

$conn->close();
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>FlyChat - Verificar Teléfono</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
     <style>
        .blue-gradient { background: linear-gradient(135deg, #0088cc 0%, #0055a5 100%); }
        .button-gradient { background: linear-gradient(135deg, #0088cc 0%, #0055a5 100%); color: white; }
        .button-gradient:hover { background: linear-gradient(135deg, #0077b3 0%, #004494 100%); }
    </style>
</head>
<body class="bg-gray-100 min-h-screen flex flex-col">
     <div class="flex-1 flex flex-col justify-center items-center p-4 sm:p-6">
        <div class="w-full max-w-md bg-white rounded-xl shadow-lg overflow-hidden">
             <!-- Header -->
            <div class="blue-gradient p-6 text-center">
                <h1 class="text-white text-2xl font-bold">FlyChat</h1>
                 <p class="text-blue-100 mt-1">Verificación de número</p>
            </div>

             <!-- Contenido -->
            <div class="p-6">
                 <!-- Mensaje de error -->
                <?php if (!empty($error)): ?>
                    <div class="mb-4 text-red-600 text-sm font-medium bg-red-100 p-3 rounded">
                        <?php echo htmlspecialchars($error); ?>
                    </div>
                <?php endif; ?>

                 <!-- Mensaje informativo / OTP simulado -->
                 <p class="text-gray-600 text-sm mb-4">
                    Se ha enviado un código de verificación (OTP) a tu número <strong><?php echo htmlspecialchars($phone_to_verify); ?></strong>.
                    Ingrésalo a continuación para completar tu registro.
                 </p>
                <?php if ($simulated_otp): ?>
                    <div class="mb-4 text-blue-600 text-sm font-bold bg-blue-100 p-3 rounded">
                        (Prueba) Tu código OTP es: <?php echo htmlspecialchars($simulated_otp); ?>
                    </div>
                <?php endif; ?>


                 <form method="post">
                     <div class="mb-6">
                        <label class="block text-gray-700 text-sm font-medium mb-2" for="otp">
                            Código OTP
                        </label>
                        <input class="shadow-sm appearance-none border rounded-lg w-full py-3 px-4 text-gray-700 leading-tight focus:outline-none focus:ring-2 focus:ring-blue-500"
                            id="otp" name="otp" type="text" inputmode="numeric" pattern="[0-9]*" placeholder="Ingresa el código de 6 dígitos" required maxlength="6">
                    </div>

                    <button type="submit" class="w-full button-gradient font-medium py-3 px-4 rounded-lg focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-opacity-50 transition-colors">
                        Verificar y Continuar
                    </button>
                 </form>

                 <div class="mt-4 text-center text-sm">
                     <a href="index.php" class="text-blue-600 hover:underline">Volver al inicio</a>
                 </div>
            </div>
        </div>
    </div>
</body>
</html>